@@ -1,10 +1,5 @@
 package Data::Sah::Filter;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
-our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use strict 'subs', 'vars';
 use warnings;
 no warnings 'once';
@@ -13,6 +8,12 @@ use Log::ger;
 use Data::Sah::FilterCommon;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-07-04'; # DATE
+our $DIST = 'Data-Sah-Filter'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 our @EXPORT_OK = qw(gen_filter);
 
 our %SPEC;
@@ -103,7 +104,7 @@ sub gen_filter {
 
     return $code if $args{source};
 
-    my $filter = eval $code;
+    my $filter = eval $code; ## no critic: BuiltinFunctions::ProhibitStringyEval
     die if $@;
     $filter;
 }
@@ -123,7 +124,7 @@ Data::Sah::Filter - Filtering for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.008 of Data::Sah::Filter (from Perl distribution Data-Sah-Filter), released on 2020-06-04.
+This document describes version 0.009 of Data::Sah::Filter (from Perl distribution Data-Sah-Filter), released on 2022-07-04.
 
 =head1 SYNOPSIS
 
@@ -273,14 +274,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-F
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Filter>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Filter>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Data::Sah>
@@ -299,11 +292,36 @@ to all filtering expressions.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Filter>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
