@@ -1,16 +1,16 @@
 package Data::Sah::Filter::perl::Str::replace_map;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
-our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 use Data::Dmp;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-07-04'; # DATE
+our $DIST = 'Data-Sah-Filter'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 sub meta {
     +{
         v => 1,
@@ -58,7 +58,7 @@ Data::Sah::Filter::perl::Str::replace_map - Replace (map) some values with (to)
 
 =head1 VERSION
 
-This document describes version 0.008 of Data::Sah::Filter::perl::Str::replace_map (from Perl distribution Data-Sah-Filter), released on 2020-06-04.
+This document describes version 0.009 of Data::Sah::Filter::perl::Str::replace_map (from Perl distribution Data-Sah-Filter), released on 2022-07-04.
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ Use in Sah schema's C<prefilters> (or C<postfilters>) clause:
 This filter rule can be used to replace some (e.g. old) values to other (e.g.
 new) values. For example, with this rule:
 
- [replace_map => {burma => "myanmar", siam => "thailand"}]
+ [replace_map => {map => {burma => "myanmar", siam => "thailand"}}]
 
 then "indonesia" or "myanmar" will be unchanged, but "burma" will be changed to
 "myanmar" and "siam" will be changed to "thailand".
@@ -86,14 +86,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-F
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Filter>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Filter>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Complete::Util>'s L<complete_array_elem|Complete::Util/complete_array_elem>
@@ -103,11 +95,36 @@ also has a C<replace_map> option.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Filter>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
